summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoPictureEps.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /lib/kofficecore/KoPictureEps.h
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'lib/kofficecore/KoPictureEps.h')
-rw-r--r--lib/kofficecore/KoPictureEps.h48
1 files changed, 24 insertions, 24 deletions
diff --git a/lib/kofficecore/KoPictureEps.h b/lib/kofficecore/KoPictureEps.h
index ba2a4cb9..23dfdaf4 100644
--- a/lib/kofficecore/KoPictureEps.h
+++ b/lib/kofficecore/KoPictureEps.h
@@ -20,10 +20,10 @@
#ifndef __koPictureEps_h__
#define __koPictureEps_h__
-#include <qstring.h>
+#include <tqstring.h>
-class QPainter;
-class QSize;
+class TQPainter;
+class TQSize;
class KoPictureEpsPrivate;
// TODO: fix documentation
@@ -66,43 +66,43 @@ public:
* Note that the image is being scaled to that size using scale() - except when printing.
* This avoids scaling the image at each paint event.
*
* The other parameters are very similar to QPainter::drawPixmap :
* (@p x, @p y) define the position in the painter,
* (@p sx, @p sy) specify the top-left point in pixmap that is to be drawn. The default is (0, 0).
* (@p sw, @p sh) specify the size of the pixmap that is to be drawn. The default, (-1, -1), means all the way to the bottom
* right of the pixmap.
*/
- virtual void draw(QPainter& painter, int x, int y, int width, int height, int sx = 0, int sy = 0, int sw = -1, int sh = -1, bool fastMode = false);
+ virtual void draw(TQPainter& painter, int x, int y, int width, int height, int sx = 0, int sy = 0, int sw = -1, int sh = -1, bool fastMode = false);
- virtual bool loadData(const QByteArray& array, const QString& extension);
+ virtual bool loadData(const TQByteArray& array, const TQString& extension);
- virtual bool save(QIODevice* io) const;
+ virtual bool save(TQIODevice* io) const;
- virtual QSize getOriginalSize(void) const;
+ virtual TQSize getOriginalSize(void) const;
- virtual QPixmap generatePixmap(const QSize& size, bool smoothScale = false);
+ virtual TQPixmap generatePixmap(const TQSize& size, bool smoothScale = false);
- virtual QString getMimeType(const QString& extension) const;
+ virtual TQString getMimeType(const TQString& extension) const;
/**
- * Generate a QImage
+ * Generate a TQImage
* (always in slow mode)
*/
- virtual QImage generateImage(const QSize& size);
+ virtual TQImage generateImage(const TQSize& size);
virtual void clearCache(void);
protected:
- QPixmap getPixmap(QImage& image);
- void scaleAndCreatePixmap(const QSize& size, bool fastMode, const int resolutionx, const int resolutiony );
- QImage scaleWithGhostScript( const QSize& size, const int resolutionx, const int resolutiony );
+ TQPixmap getPixmap(TQImage& image);
+ void scaleAndCreatePixmap(const TQSize& size, bool fastMode, const int resolutionx, const int resolutiony );
+ TQImage scaleWithGhostScript( const TQSize& size, const int resolutionx, const int resolutiony );
bool extractPostScriptStream( void );
private:
- int tryScaleWithGhostScript(QImage &image, const QSize& size, const int resolutionx, const int resolutiony, const char* device );
+ int tryScaleWithGhostScript(TQImage &image, const TQSize& size, const int resolutionx, const int resolutiony, const char* device );
/**
* @brief Read a line from a PostScript stream in a QByteArray
*
* The PostScript stream is somewhere in the QByteArray and therefore has to be
* determined by the start and length of this stream and the current position
*
* @param array the array which is read
@@ -113,17 +113,17 @@ private:
* to skip an eventual Line Feed at the start of this line
* @return the read line
*/
- QString readLine( const QByteArray& array, const uint start, const uint length, uint& pos, bool& lastCharWasCr );
+ TQString readLine( const TQByteArray& array, const uint start, const uint length, uint& pos, bool& lastCharWasCr );
private:
/**
* Copy of the loaded EPS file
*/
- QByteArray m_rawData;
- QPixmap m_cachedPixmap; ///< Cached pixmap
- QSize m_originalSize; ///< Original size of the EPS picture
- QSize m_cachedSize; ///< size of the currently cached pixmap @see m_cachedPixmap
- QRect m_boundingBox; ///< Bounding box, as read from the EPS file
+ TQByteArray m_rawData;
+ TQPixmap m_cachedPixmap; ///< Cached pixmap
+ TQSize m_originalSize; ///< Original size of the EPS picture
+ TQSize m_cachedSize; ///< size of the currently cached pixmap @see m_cachedPixmap
+ TQRect m_boundingBox; ///< Bounding box, as read from the EPS file
uint m_psStreamStart; ///< Start position of the PostScript stream (like if it was a MS-DOS EPS file)
uint m_psStreamLength; ///< Lenght of the PostScript stream (like if it was a MS-DOS EPS file)
/**
@@ -66,43 +66,43 @@ public:
* This avoids scaling the image at each paint event.
*
- * The other parameters are very similar to QPainter::drawPixmap :
+ * The other parameters are very similar to TQPainter::drawPixmap :
* (@p x, @p y) define the position in the painter,
* (@p sx, @p sy) specify the top-left point in pixmap that is to be drawn. The default is (0, 0).
@@ -66,43 +66,43 @@ public:
/**
- * @brief Read a line from a PostScript stream in a QByteArray
+ * @brief Read a line from a PostScript stream in a TQByteArray
*
@@ -66,43 +66,43 @@ public:
*
- * The PostScript stream is somewhere in the QByteArray and therefore has to be
+ * The PostScript stream is somewhere in the TQByteArray and therefore has to be
* determined by the start and length of this stream and the current position
*